/* automatically generated from pulseaudio-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (pulseaudio_dialog_ui)
#endif
#ifdef __GNUC__
static const char pulseaudio_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char pulseaudio_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.11\"/"
  "><object class=\"GtkAdjustment\" id=\"adjustment-volume-step\"><propert"
  "y name=\"lower\">1</property><property name=\"upper\">50</property><pro"
  "perty name=\"value\">5</property><property name=\"step_increment\">1</p"
  "roperty><property name=\"page_increment\">10</property></object><object"
  " class=\"GtkImage\" id=\"image1\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"icon"
  "_name\">xfce4-pulseaudio-plugin</property></object><object class=\"GtkI"
  "mage\" id=\"image2\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"icon_name\">edit-"
  "clear</property></object><object class=\"GtkListStore\" id=\"liststore1"
  "\"><columns><column type=\"GIcon\"/><column type=\"gchararray\"/><colum"
  "n type=\"gchararray\"/><column type=\"gboolean\"/></columns></object><o"
  "bject class=\"GtkListStore\" id=\"notifications-store\"><columns><colum"
  "n type=\"gchararray\"/></columns><data><row><col id=\"0\" translatable="
  "\"yes\">None</col></row><row><col id=\"0\" translatable=\"yes\">All</co"
  "l></row><row><col id=\"0\" translatable=\"yes\">Output only</col></row>"
  "<row><col id=\"0\" translatable=\"yes\">Input only</col></row></data></"
  "object><object class=\"XfceTitledDialog\" id=\"dialog\"><property name="
  "\"can_focus\">False</property><property name=\"title\" translatable=\"y"
  "es\">PulseAudio Panel Plugin</property><property name=\"default_width\""
  ">425</property><property name=\"default_height\">525</property><propert"
  "y name=\"icon_name\">gtk-properties</property><property name=\"type_hin"
  "t\">normal</property><child internal-child=\"vbox\"><object class=\"Gtk"
  "Box\" id=\"dialog-vbox2\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">2</property><child inter"
  "nal-child=\"action_area\"><object class=\"GtkButtonBox\" id=\"dialog-ac"
  "tion_area2\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"layout_style\">end</proper"
  "ty><child><object class=\"GtkButton\" id=\"close-button\"><property nam"
  "e=\"label\">gtk-close</property><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">True</property><property name=\"receive"
  "s_default\">True</property><property name=\"use_stock\">True</property>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">False</property><property name=\"position\">0</property></"
  "packing></child><child><object class=\"GtkButton\" id=\"help-button\"><"
  "property name=\"label\">gtk-help</property><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"receives_default\">True</property><property name=\"use_stock\">True"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">False</property><property name=\"position\">1</"
  "property><property name=\"secondary\">True</property></packing></child>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">True</property><property name=\"pack_type\">end</property>"
  "<property name=\"position\">0</property></packing></child><child><objec"
  "t class=\"GtkNotebook\" id=\"sections\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">True</property><property name=\""
  "border_width\">6</property><child><object class=\"GtkBox\" id=\"section"
  "_general_content\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"border_width\">12</"
  "property><property name=\"orientation\">vertical</property><property na"
  "me=\"spacing\">18</property><child><object class=\"GtkFrame\" id=\"fram"
  "e1\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"label_xalign\">0</property><prope"
  "rty name=\"shadow_type\">none</property><child><object class=\"GtkAlign"
  "ment\" id=\"alignment1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"top_padding\""
  ">6</property><property name=\"left_padding\">12</property><child><objec"
  "t class=\"GtkBox\" id=\"vbox2\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"orient"
  "ation\">vertical</property><property name=\"spacing\">6</property><chil"
  "d><object class=\"GtkCheckButton\" id=\"checkbutton-keyboard-shortcuts\""
  "><property name=\"label\" translatable=\"yes\">Enable keyboard _shortcu"
  "ts for volume control</property><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">True</property><property name=\"receive"
  "s_default\">False</property><property name=\"tooltip_text\" translatabl"
  "e=\"yes\">Enables volume control using multimedia keys. Make sure no ot"
  "her application that listens to these keys (e.g. xfce4-volumed) is runn"
  "ing in the background.</property><property name=\"halign\">start</prope"
  "rty><property name=\"use_underline\">True</property><property name=\"dr"
  "aw_indicator\">True</property></object><packing><property name=\"expand"
  "\">True</property><property name=\"fill\">True</property><property name"
  "=\"position\">0</property></packing></child><child><object class=\"GtkC"
  "heckButton\" id=\"checkbutton-play-sound\"><property name=\"label\" tra"
  "nslatable=\"yes\">Play system _sound when volume changes</property><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"receives_default\">False</property><propert"
  "y name=\"tooltip_text\" translatable=\"yes\">Enables audio feedback whe"
  "n using multimedia keys to change the volume.</property><property name="
  "\"halign\">start</property><property name=\"use_underline\">True</prope"
  "rty><property name=\"draw_indicator\">True</property></object><packing>"
  "<property name=\"expand\">True</property><property name=\"fill\">True</"
  "property><property name=\"position\">1</property></packing></child><chi"
  "ld><object class=\"GtkBox\" id=\"vbox2-hbox2\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"spacing\">6</property><child><object class=\"GtkLabel\" id=\"l"
  "abel5\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"label\" translatable=\"yes\">S"
  "how volume _notifications:</property><property name=\"use_underline\">T"
  "rue</property><property name=\"mnemonic_widget\">combobox-notifications"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkComboBox\" id=\"com"
  "bobox-notifications\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"tooltip_text\" t"
  "ranslatable=\"yes\">Mute/unmute is notified in all modes except \"None\""
  "</property><property name=\"model\">notifications-store</property><chil"
  "d><object class=\"GtkCellRendererText\" id=\"cb_text_render\"/><attribu"
  "tes><attribute name=\"text\">0</attribute></attributes></child></object"
  "><packing><property name=\"expand\">False</property><property name=\"fi"
  "ll\">True</property><property name=\"position\">1</property></packing><"
  "/child></object><packing><property name=\"expand\">True</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">2</proper"
  "ty></packing></child><child><object class=\"GtkBox\" id=\"vbox2-hbox1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"tooltip_text\" translatable=\"yes\">S"
  "tep size used when adjusting volume with mouse wheel.</property><proper"
  "ty name=\"spacing\">6</property><child><object class=\"GtkLabel\" id=\""
  "label4\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "Mouse wheel volume step:</property><property name=\"use_underline\">Tru"
  "e</property></object><packing><property name=\"expand\">False</property"
  "><property name=\"fill\">True</property><property name=\"position\">0</"
  "property></packing></child><child><object class=\"GtkSpinButton\" id=\""
  "spinbutton-volume-step\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">True</property><property name=\"hexpand\">True"
  "</property><property name=\"halign\">start</property><property name=\"m"
  "ax_length\">2</property><property name=\"width_chars\">2</property><pro"
  "perty name=\"max_width_chars\">3</property><property name=\"caps_lock_w"
  "arning\">False</property><property name=\"adjustment\">adjustment-volum"
  "e-step</property><property name=\"climb_rate\">1</property><property na"
  "me=\"snap_to_ticks\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child></object><packing><p"
  "roperty name=\"expand\">False</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">3</property></packing></child></obj"
  "ect></child></object></child><child type=\"label\"><object class=\"GtkL"
  "abel\" id=\"label1\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"label\" translata"
  "ble=\"yes\">Behaviour</property><attributes><attribute name=\"weight\" "
  "value=\"bold\"/></attributes></object></child></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">0</property></packing></child><child><ob"
  "ject class=\"GtkFrame\" id=\"frame2\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">False</property><property name=\""
  "label_xalign\">0</property><property name=\"shadow_type\">none</propert"
  "y><child><object class=\"GtkAlignment\" id=\"alignment2\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"top_padding\">6</property><property name=\"left_pad"
  "ding\">12</property><child><object class=\"GtkGrid\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"row_spacing\">6</property><property name=\"column_spacin"
  "g\">12</property><child><object class=\"GtkLabel\" id=\"label2\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"label\" translatable=\"yes\">Audio _Mixer</p"
  "roperty><property name=\"use_underline\">True</property></object><packi"
  "ng><property name=\"left_attach\">0</property><property name=\"top_atta"
  "ch\">0</property></packing></child><child><object class=\"GtkEntry\" id"
  "=\"entry-mixer-command\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">True</property><property name=\"tooltip_text\""
  " translatable=\"yes\">Audio mixer command that can be executed from the"
  " context menu, e.g. \"pavucontrol\", \"unity-control-center sound\".</p"
  "roperty><property name=\"hexpand\">True</property><property name=\"invi"
  "sible_char\">\342\200\242</property><property name=\"primary_icon_activ"
  "atable\">False</property><property name=\"secondary_icon_activatable\">"
  "False</property></object><packing><property name=\"left_attach\">1</pro"
  "perty><property name=\"top_attach\">0</property></packing></child><chil"
  "d><object class=\"GtkButton\" id=\"button-run-mixer\"><property name=\""
  "label\" translatable=\"yes\">_Run Audio Mixer...</property><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"receives_default\">True</property><property name=\""
  "halign\">start</property><property name=\"image\">image1</property><pro"
  "perty name=\"use_underline\">True</property></object><packing><property"
  " name=\"left_attach\">0</property><property name=\"top_attach\">1</prop"
  "erty><property name=\"width\">2</property></packing></child></object></"
  "child></object></child><child type=\"label\"><object class=\"GtkLabel\""
  " id=\"label3\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">Sound Settings</property><attributes><attribute name=\"weight\" v"
  "alue=\"bold\"/></attributes></object></child></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">1</property></packing></child></object></"
  "child><child type=\"tab\"><object class=\"GtkLabel\" id=\"section_gener"
  "al\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"label\" translatable=\"yes\">Gene"
  "ral</property></object><packing><property name=\"tab_fill\">False</prop"
  "erty></packing></child><child><object class=\"GtkBox\" id=\"section_mp_"
  "content\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"margin_left\">10</property><"
  "property name=\"margin_right\">10</property><property name=\"margin_top"
  "\">7</property><property name=\"margin_bottom\">12</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">18</"
  "property><child><object class=\"GtkBox\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"margin_left\">2</property><property name=\"margin_right\">2</propert"
  "y><property name=\"orientation\">vertical</property><child><object clas"
  "s=\"GtkBox\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"spacing\">12</property><ch"
  "ild><object class=\"GtkLabel\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"label\""
  " translatable=\"yes\">Control Playback of Media Players</property><attr"
  "ibutes><attribute name=\"weight\" value=\"bold\"/></attributes></object"
  "><packing><property name=\"expand\">False</property><property name=\"fi"
  "ll\">True</property><property name=\"position\">0</property></packing><"
  "/child><child><object class=\"GtkSwitch\" id=\"switch-mpris-support\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">T"
  "rue</property></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">True</property><property name=\"pack_type\">"
  "end</property><property name=\"position\">1</property></packing></child"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">True</property><property name=\"position\">0</property></"
  "packing></child><child><object class=\"GtkAlignment\" id=\"section_mp_c"
  "ontent_1\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"left_padding\">12</property"
  "><child><object class=\"GtkBox\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"orien"
  "tation\">vertical</property><property name=\"spacing\">6</property><chi"
  "ld><object class=\"GtkCheckButton\" id=\"checkbutton-multimedia-keys\">"
  "<property name=\"label\" translatable=\"yes\">Enable multimedia keys fo"
  "r playback control</property><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">False</property><property name=\"halign\">start</property><pro"
  "perty name=\"draw_indicator\">True</property></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">0</property></packing></child><child><obj"
  "ect class=\"GtkCheckButton\" id=\"checkbutton-wnck\"><property name=\"l"
  "abel\" translatable=\"yes\">Enable experimental window focus support</p"
  "roperty><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"receives_default\">False</prope"
  "rty><property name=\"halign\">start</property><property name=\"draw_ind"
  "icator\">True</property></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child></object></child></object><packi"
  "ng><property name=\"expand\">False</property><property name=\"fill\">Tr"
  "ue</property><property name=\"position\">1</property></packing></child>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">0</property></p"
  "acking></child><child><object class=\"GtkFrame\" id=\"section_mp_conten"
  "t_2\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"margin_left\">2</property><prope"
  "rty name=\"margin_right\">2</property><property name=\"margin_bottom\">"
  "12</property><property name=\"label_xalign\">0</property><property name"
  "=\"shadow_type\">none</property><child><object class=\"GtkAlignment\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"top_padding\">6</property><property nam"
  "e=\"left_padding\">12</property><child><object class=\"GtkBox\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"orientation\">vertical</property><property na"
  "me=\"spacing\">6</property><child><object class=\"GtkScrolledWindow\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">T"
  "rue</property><property name=\"shadow_type\">in</property><child><objec"
  "t class=\"GtkTreeView\" id=\"player_tree_view\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">True</property><propert"
  "y name=\"model\">liststore1</property><property name=\"headers_clickabl"
  "e\">False</property><property name=\"enable_search\">False</property><p"
  "roperty name=\"show_expanders\">False</property><child internal-child=\""
  "selection\"><object class=\"GtkTreeSelection\"/></child><child><object "
  "class=\"GtkTreeViewColumn\" id=\"col_icon\"><child><object class=\"GtkC"
  "ellRendererPixbuf\" id=\"col_icon_renderer\"/><attributes><attribute na"
  "me=\"gicon\">0</attribute></attributes></child></object></child><child>"
  "<object class=\"GtkTreeViewColumn\" id=\"col_label\"><property name=\"t"
  "itle\" translatable=\"yes\">Title</property><property name=\"expand\">T"
  "rue</property><child><object class=\"GtkCellRendererText\" id=\"col_lab"
  "el_renderer\"/><attributes><attribute name=\"text\">2</attribute></attr"
  "ibutes></child></object></child><child><object class=\"GtkTreeViewColum"
  "n\" id=\"col_hidden\"><property name=\"title\" translatable=\"yes\">Hid"
  "den</property><child><object class=\"GtkCellRendererToggle\" id=\"col_h"
  "idden_renderer\"/><attributes><attribute name=\"active\">3</attribute><"
  "/attributes></child></object></child></object></child></object><packing"
  "><property name=\"expand\">True</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkButton\" id=\"clear_players\"><property name=\"l"
  "abel\" translatable=\"yes\">Clear Known Items</property><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<property name=\"receives_default\">True</property><property name=\"hal"
  "ign\">start</property><property name=\"image\">image2</property></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">False</property><property name=\"position\">1</property></packing"
  "></child><child><object class=\"GtkRevealer\" id=\"restart_revealer\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><child><object class=\"GtkLabel\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"halign\">start</property><property name=\"label\" translatab"
  "le=\"yes\">Please restart your panel for additional players to be displ"
  "ayed.</property><property name=\"wrap\">True</property><property name=\""
  "xalign\">0</property><attributes><attribute name=\"style\" value=\"ital"
  "ic\"/></attributes></object></child></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">2</property></packing></child></object></child></o"
  "bject></child><child type=\"label\"><object class=\"GtkLabel\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"label\" translatable=\"yes\">Known Media Playe"
  "rs</property><attributes><attribute name=\"weight\" value=\"bold\"/></a"
  "ttributes></object></child></object><packing><property name=\"expand\">"
  "True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"position\">1</property></packing></child><child type=\"tab\"><obje"
  "ct class=\"GtkLabel\" id=\"section_mp\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label\" translatable=\"yes\">Media Players</property></object><packin"
  "g><property name=\"position\">1</property><property name=\"tab_fill\">F"
  "alse</property></packing></child><child><placeholder/></child><child ty"
  "pe=\"tab\"><placeholder/></child></object><packing><property name=\"exp"
  "and\">True</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">1</property></packing></child></object></child><action"
  "-widgets><action-widget response=\"0\">close-button</action-widget><act"
  "ion-widget response=\"0\">help-button</action-widget></action-widgets><"
  "/object></interface>"
};

static const unsigned pulseaudio_dialog_ui_length = 20260u;

